Apply "QC checks" on calculated metrics and station/sample attributes to "flag" samples for the user. Examples include watershed size or total number of individuals. Can have checks for both high and low values. Checks are stored in separate file. For structure see df.checks in example.

qc.checks(df.metrics, df.checks, input.shape = "wide")

Arguments

df.metrics

Wide data frame with metric values to be evaluated.

df.checks

Data frame of metric thresholds to check.

input.shape

Shape of df.metrics; wide or long. Default is wide.

Value

Returns a data frame of SampleID checks and results; Pass and Fail.

Details

used reshape2 package

Examples

library(readxl)

# Calculate Metrics
df.samps.bugs <- read_excel(system.file("./extdata/Data_Benthos.xlsx",
                                        package="BioMonTools"),
                            guess_max = 10^6)

# Columns to keep
myCols <- c("Area_mi2", "SurfaceArea", "Density_m2", "Density_ft2")

# Run Function
myDF <- df.samps.bugs
df.metric.values.bugs <- metric.values(myDF, "bugs", fun.cols2keep = myCols)
#>  
#> There are 1 missing fields in the data:
#> SAMP_AREA_M2
#>  
#> If you continue the metrics associated with these fields will be invalid.
#> For example, if the HABIT field is missing all habit related metrics will not be correct.
#> Do you wish to continue (YES or NO)?
#> boo.Shiny == TRUE and interactive == FALSE
#>                so prompt skipped and value set to '1'.
#> Warning: Metrics related to the following fields are invalid:
#>    SAMP_AREA_M2
#> Updated col class; TOLVAL2 to numeric
#> Joining with `by = join_by(SAMPLEID, INDEX_NAME, INDEX_CLASS)`

# Import Checks
df.checks <- read_excel(system.file("./extdata/MetricFlags.xlsx",
                                    package="BioMonTools"),
                        sheet="Flags")

# Run Function
df.flags <- qc.checks(df.metric.values.bugs, df.checks)

# Summarize Results
table(df.flags[, "CHECKNAME"], df.flags[, "FLAG"], useNA = "ifany")
#>                                  
#>                                   FAIL PASS <NA>
#>   Low density (ft2)                  0    0   47
#>   Ramellogammarus                    0   47    0
#>   brackish organisms present         0   47    0
#>   catchment, Large                   0   47    0
#>   catchment, small                  10   37    0
#>   individuals, Large                 0   47    0
#>   individuals, dominant 02, Large   46    1    0
#>   individuals, small                47    0    0
#>   surface area, small                7   37    3