This function has been deprecated (March 2026).
qc_taxa(
DF_User,
DF_Official = NULL,
fun.Community = NULL,
useOfficialTaxaInfo = "only_Official"
)User taxa data.
Official master taxa list. Can be a local file or from a URL. Default is NULL. A NULL value will use the official online files.
Community name for which to compare the master taxa list (bugs or fish).
Select how to handle new/different taxa. See 'Details' for more information. Valid values are "only_Official", "only_user", "add_new". Default = "only_Official".
input data frame with master taxa information added to it.
The new function is qc_taxa_match_official.
This function exists only as a wrapper to avoid breaking older code.