Performs basic QC of a numeric column showing all values.
qc_taxa_values_numeric(
data,
col_vals = NULL,
valid_min = NULL,
valid_max = NULL
)A data frame with col_vals values, occurrence (n), and valid (TRUE/FALSE) within range of valid_min and valid_max.
Returns a data frame of the values from the input with counts (column = n) from the specified column. User provided valid_min and valid_max are applied to each set of values and evaluated as valid TRUE or FALSE.
The BioMonTools accepted values for TolVal are 0 - 10.
The BioMonTools accepted values for UFC are 1 - 6.
# TolVal
qc_taxa_values_numeric(data_benthos_MBSS, "TOLVAL", 0, 10)
#> Error: 'valid_min' is missing.
# TolVal2
qc_taxa_values_numeric(data_benthos_MBSS, "TOLVAL2", 0, 10)
#> Error: 'valid_min' is missing.
# UFC
qc_taxa_values_numeric(data_benthos_MBSS, "UFC", 1, 6)
#> Error: 'valid_min' is missing.